package App::SFDC;

use strict;
use warnings;
use 5.12.0;

our $VERSION = '0.07'; # VERSION

sub import {
  my $class = shift;

  require "App/SFDC/$_.pm" ## no critic
    for @_ || qw'Retrieve Deploy'

}

1;

__END__

=pod

=head1 NAME

App::SFDC

=head1 VERSION

version 0.07

=head1 AUTHOR

Alexander Brett <alexander.brett@sophos.com>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2015 by Sophos Limited.

This is free software, licensed under:

  The MIT (X11) License

The full text of the license can be found in the
F<LICENSE> file included with this distribution.

=cut
